==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Text/ts/Text_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../TextDialog/CharacterMapDialog.ui" line="+14"/>
        <source>Character Map</source>
        <translation>Table des caractères</translation>
    </message>
</context>
<context>
    <name>Text</name>
    <message>
        <location filename="../Text.js" line="+88"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../TextInit.js" line="+2"/>
        <source>&amp;Text</source>
        <translation>&amp;Texte</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw text</source>
        <translation>Dessinez texte</translation>
    </message>
    <message>
        <location filename="../Text.ui" line="+17"/>
        <source>Contents:</source>
        <translation>Sommaire :</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Height:</source>
        <translation>Hauteur : </translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Angle:</source>
        <translation>Angle :</translation>
    </message>
</context>
<context>
    <name>TextDialog</name>
    <message>
        <location filename="../TextDialog/TextDialog.js" line="+242"/>
        <source>Default value:</source>
        <translation>Valeur par défaut :</translation>
    </message>
    <message>
        <location line="+260"/>
        <source>&amp;Undo</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Redo</source>
        <translation>&amp;Rétablir</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Cu&amp;t</source>
        <translation>Co&amp;uper</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copier</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Paste</source>
        <translation>Co&amp;ller</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Bold</source>
        <translation>&amp;Gras</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Italic</source>
        <translation>&amp;Italique</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Subscript</source>
        <translation>&amp;Indice</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Superscript</source>
        <translation>&amp;Exposant</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>&amp;Color...</source>
        <translation>&amp;Couleur...</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Special Characters...</source>
        <translation>&amp;Caractère spécial...</translation>
    </message>
    <message>
        <location line="+310"/>
        <source>Others...</source>
        <translation>Autres...</translation>
    </message>
    <message>
        <location line="+131"/>
        <source>Degree</source>
        <translation>Degré</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plus-Minus</source>
        <translation>Plus-minus</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Diameter</source>
        <translation>Diamètre</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal</source>
        <translation>Presque égale</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Multiplication</source>
        <translation>Multiplication</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Division</source>
        <translation>Division</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translation>Delta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pi</source>
        <translation>Pi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Identity</source>
        <translation>Identité</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Not equal</source>
        <translation>Inégalité</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ohm</source>
        <translation>Ohm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Omega</source>
        <translation>Omega</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Squared</source>
        <translation>Quadrature</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cubed</source>
        <translation>Cubique</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No-break space</source>
        <translation>Espace insécable</translation>
    </message>
    <message>
        <location filename="../TextDialog/TextDialog.ui" line="+14"/>
        <source>Text</source>
        <translation>Texte</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Main Font</source>
        <translation>Police principal</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Height:</source>
        <translation>Hauteur : </translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Text Height in Drawing Units</source>
        <translation>Hauteur du texte en unités de dessin</translation>
    </message>
    <message>
        <location line="+18"/>
        <location line="+213"/>
        <source>Bold</source>
        <translation>Gras</translation>
    </message>
    <message>
        <location line="-206"/>
        <location line="+219"/>
        <source>Italic</source>
        <translation>Italique</translation>
    </message>
    <message>
        <location line="-202"/>
        <source>Simple text
(one line, no formatting)</source>
        <translation>Texte simple</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Rich Text</source>
        <translation>Texte riche</translation>
    </message>
    <message>
        <location line="-24"/>
        <source>Text fits on one line and has no formatting</source>
        <translation>Texte tient sur une seule ligne et n&apos;a pas de formatage</translation>
    </message>
    <message>
        <source>Simple Text</source>
        <translation type="obsolete">Texte simple</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Cut</source>
        <translation>Couper</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Paste</source>
        <translation>Coller</translation>
    </message>
    <message>
        <location line="+115"/>
        <source>Ctrl+B</source>
        <translation>CTRL+B</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Insert Symbol...</source>
        <translation>Insérer symbole...</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Source</source>
        <translation>Source</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Attribute Details</source>
        <translation>Détails des attributs</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tag:</source>
        <translation>Étiquette :</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Prompt:</source>
        <translation>Invite :</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Value:</source>
        <translation>Valeur :</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Text Geometry</source>
        <translation>Géométrie du texte</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Line spacing factor:</source>
        <translation>Espacement lignes :</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Line Spacing Factor</source>
        <translation>Facteur espacement lignes</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Angle:</source>
        <translation>Angle :</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Rotation Angle</source>
        <translation>Angle de rotation</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Alignment</source>
        <translation>Alignement</translation>
    </message>
    <message>
        <location line="+79"/>
        <source>Top Center</source>
        <translation>En haut au centre</translation>
    </message>
    <message>
        <location line="+145"/>
        <source>Base Left</source>
        <translation>En base à gauche</translation>
    </message>
    <message>
        <location line="-177"/>
        <source>Top Left</source>
        <translation>En haut à gauche</translation>
    </message>
    <message>
        <location line="+206"/>
        <source>Base Center</source>
        <translation>En base au centre</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Base Right</source>
        <translation>En base à droite</translation>
    </message>
    <message>
        <location line="-145"/>
        <source>Top Right</source>
        <translation>En haut à droite</translation>
    </message>
    <message>
        <location line="+203"/>
        <source>Bottom Center</source>
        <translation>En bas au centre</translation>
    </message>
    <message>
        <location line="-145"/>
        <source>Middle Left</source>
        <translation>Au milieu à gauche</translation>
    </message>
    <message>
        <location line="-29"/>
        <source>Middle Center</source>
        <translation>Au milieu au centre</translation>
    </message>
    <message>
        <location line="-58"/>
        <source>Middle Right</source>
        <translation>Au milieu à droite</translation>
    </message>
    <message>
        <location line="+203"/>
        <source>Bottom Left</source>
        <translation>En bas à gauche</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Bottom Right</source>
        <translation>En bas à droite</translation>
    </message>
    <message>
        <location line="+59"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Text/ts/Text_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../TextDialog/CharacterMapDialog.ui" line="+14"/>
        <source>Character Map</source>
        <translation>Table des caractères</translation>
    </message>
</context>
<context>
    <name>Text</name>
    <message>
        <location filename="../Text.js" line="+88"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../TextInit.js" line="+2"/>
        <source>&amp;Text</source>
        <translation>&amp;Texte</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw text</source>
        <translation>Dessinez texte</translation>
    </message>
    <message>
        <location filename="../Text.ui" line="+17"/>
        <source>Contents:</source>
        <translation>Sommaire :</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Height:</source>
        <translation>Hauteur&#xa0;: </translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Angle:</source>
        <translation>Angle :</translation>
    </message>
</context>
<context>
    <name>TextDialog</name>
    <message>
        <location filename="../TextDialog/TextDialog.js" line="+242"/>
        <source>Default value:</source>
        <translation>Valeur par défaut :</translation>
    </message>
    <message>
        <location line="+266"/>
        <source>&amp;Undo</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Redo</source>
        <translation>&amp;Rétablir</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Cu&amp;t</source>
        <translation>Co&amp;uper</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copier</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Paste</source>
        <translation>Co&amp;ller</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Bold</source>
        <translation>&amp;Gras</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Italic</source>
        <translation>&amp;Italique</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Subscript</source>
        <translation>&amp;Indice</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Superscript</source>
        <translation>&amp;Exposant</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>&amp;Color...</source>
        <translation>&amp;Couleur...</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Special Characters...</source>
        <translation>&amp;Caractère spécial...</translation>
    </message>
    <message>
        <location line="+305"/>
        <source>Others...</source>
        <translation>Autres...</translation>
    </message>
    <message>
        <location line="+131"/>
        <source>Degree</source>
        <translation>Degré</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plus-Minus</source>
        <translation>Plus-minus</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Diameter</source>
        <translation>Diamètre</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal</source>
        <translation>Presque égale</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Multiplication</source>
        <translation>Multiplication</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Division</source>
        <translation>Division</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translation>Delta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pi</source>
        <translation>Pi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Identity</source>
        <translation>Identité</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Not equal</source>
        <translation>Inégalité</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ohm</source>
        <translation>Ohm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Omega</source>
        <translation>Omega</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Squared</source>
        <translation>Quadrature</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cubed</source>
        <translation>Cubique</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No-break space</source>
        <translation>Espace insécable</translation>
    </message>
    <message>
        <location filename="../TextDialog/TextDialog.ui" line="+14"/>
        <source>Text</source>
        <translation>Texte</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Main Font</source>
        <translation>Police principal</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Height:</source>
        <translation>Hauteur&#xa0;: </translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Text Height in Drawing Units</source>
        <translation>Hauteur du texte en unités de dessin</translation>
    </message>
    <message>
        <location line="+18"/>
        <location line="+268"/>
        <source>Bold</source>
        <translation>Gras</translation>
    </message>
    <message>
        <location line="-261"/>
        <location line="+274"/>
        <source>Italic</source>
        <translation>Italique</translation>
    </message>
    <message>
        <location line="-257"/>
        <source>Simple text
(one line, no formatting)</source>
        <translation>Texte simple</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Rich Text</source>
        <translation>Texte riche</translation>
    </message>
    <message>
        <location line="-24"/>
        <source>Text fits on one line and has no formatting</source>
        <translation>Texte tient sur une seule ligne et n&apos;a pas de formatage</translation>
    </message>
    <message>
        <source>Simple Text</source>
        <translation type="obsolete">Texte simple</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Cut</source>
        <translation>Couper</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Paste</source>
        <translation>Coller</translation>
    </message>
    <message>
        <location line="+170"/>
        <source>Ctrl+B</source>
        <translation>CTRL+B</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Insert Symbol...</source>
        <translation>Insérer symbole...</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Source</source>
        <translation>Source</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Attribute Details</source>
        <translation>Détails des attributs</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tag:</source>
        <translation>Étiquette :</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Prompt:</source>
        <translation>Invite :</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Value:</source>
        <translation>Valeur :</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Text Geometry</source>
        <translation>Géométrie du texte</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Line spacing factor:</source>
        <translation>Espacement lignes :</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Line Spacing Factor</source>
        <translation>Facteur espacement lignes</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Angle:</source>
        <translation>Angle :</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Rotation Angle</source>
        <translation>Angle de rotation</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Alignment</source>
        <translation>Alignement</translation>
    </message>
    <message>
        <location line="+79"/>
        <source>Top Center</source>
        <translation>En haut au centre</translation>
    </message>
    <message>
        <location line="+145"/>
        <source>Base Left</source>
        <translation>En base à gauche</translation>
    </message>
    <message>
        <location line="-177"/>
        <source>Top Left</source>
        <translation>En haut à gauche</translation>
    </message>
    <message>
        <location line="+206"/>
        <source>Base Center</source>
        <translation>En base au centre</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Base Right</source>
        <translation>En base à droite</translation>
    </message>
    <message>
        <location line="-145"/>
        <source>Top Right</source>
        <translation>En haut à droite</translation>
    </message>
    <message>
        <location line="+203"/>
        <source>Bottom Center</source>
        <translation>En bas au centre</translation>
    </message>
    <message>
        <location line="-145"/>
        <source>Middle Left</source>
        <translation>Au milieu à gauche</translation>
    </message>
    <message>
        <location line="-29"/>
        <source>Middle Center</source>
        <translation>Au milieu au centre</translation>
    </message>
    <message>
        <location line="-58"/>
        <source>Middle Right</source>
        <translation>Au milieu à droite</translation>
    </message>
    <message>
        <location line="+203"/>
        <source>Bottom Left</source>
        <translation>En bas à gauche</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Bottom Right</source>
        <translation>En bas à droite</translation>
    </message>
    <message>
        <location line="+59"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
</TS>
